"""
    Registry API

    Registry API enabling advanced search on PDS data and metadata. The API provides end-points to search for bundles, collections and any PDS products with advanced search queries. It also enables to browse the archive hierarchically downward (e.g. collection/s products) or upward (e.g. bundles containing a product). The detailed syntax for querying the end-point is given in the reference documentation.   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: pds-operator@jpl.nasa.gov
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from pds.api_client.api_client import ApiClient, Endpoint as _Endpoint
from pds.api_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from pds.api_client.model.error_message import ErrorMessage
from pds.api_client.model.pds_products import PdsProducts


class ProductsContainingBundlesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.bundles_containing_product_endpoint = _Endpoint(
            settings={
                'response_type': (PdsProducts,),
                'auth': [],
                'endpoint_path': '/products/{identifier}/bundles',
                'operation_id': 'bundles_containing_product',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'identifier',
                    'fields',
                    'limit',
                    'sort',
                    'start',
                    'summary_only',
                ],
                'required': [
                    'identifier',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'limit',
                    'start',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_minimum': 1,
                    },
                    ('start',): {

                        'inclusive_minimum': 0,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'identifier':
                        (str,),
                    'fields':
                        ([str],),
                    'limit':
                        (int,),
                    'sort':
                        ([str],),
                    'start':
                        (int,),
                    'summary_only':
                        (bool,),
                },
                'attribute_map': {
                    'identifier': 'identifier',
                    'fields': 'fields',
                    'limit': 'limit',
                    'sort': 'sort',
                    'start': 'start',
                    'summary_only': 'summary-only',
                },
                'location_map': {
                    'identifier': 'path',
                    'fields': 'query',
                    'limit': 'query',
                    'sort': 'query',
                    'start': 'query',
                    'summary_only': 'query',
                },
                'collection_format_map': {
                    'fields': 'multi',
                    'sort': 'multi',
                }
            },
            headers_map={
                'accept': [
                    '*/*',
                    'application/csv',
                    'application/json',
                    'application/kvp+json',
                    'application/vnd.nasa.pds.pds4+json',
                    'application/vnd.nasa.pds.pds4+xml',
                    'application/xml',
                    'text/csv',
                    'text/html',
                    'text/xml'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def bundles_containing_product(
        self,
        identifier,
        **kwargs
    ):
        """returns one or more bundles that contain or reference the product specified by identifier selected from all PDS data products, including bundles, collections, documentation, context and observational products. See identifier for details on how it determines what is returned.   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bundles_containing_product(identifier, async_req=True)
        >>> result = thread.get()

        Args:
            identifier (str): syntax: lidvid or lid  behavior (lid): returns one or more items whose lid matches this lid exactly. If the endpoint ends with the identifier or /latest then a signle result is returned and it is the highest version. If the endpoint ends with /all then all versions of the lid are returned.  behavior (lidvid): returns one and only one item whose lidvid matches this lidvid exactly.  note: the current lid/lidvid resolution will match all the lids that start with lid. In other words, it acts like a glob of foobar*. It behaves this way from first character to the last  note: simple sorting of the lidvid is being done to select the latest from the end of the list. However, the versions 1.0, 2.0, and 13.0 will sort to 1.0, 13.0, and 2.0 so the end of the list may not be the latest. 

        Keyword Args:
            fields ([str]): syntax: fields=field1,field2,...  behavior: this parameter and the headder Accept: type determine what content is packaged for the result. While the types application/csv, application/kvp+json, and text/csv return only the fields requesteted, all of the other types have a minimal set of fields that must be returned. Duplicating a minimally required field in this parameter has not effect. The types vnd.nasa.pds.pds4+json and vnd.nasa.pds.pds4+xml have a complete set of fields that must be returned; meaning this parameter does not impact their content. When fields is not used, then the minimal set of fields, or all when minimal is an empty set, is returned.  notes: the blob fields are blocked unless specifically requrested and only for the */csv and application/kvp+csv types. . [optional]
            limit (int): syntax: limit=10  behavior: maximum number of matching results returned, for pagination . [optional] if omitted the server will use the default value of 100
            sort ([str]): syntax: sort=asc(field0),desc(field1),...  behavior: is this implemented? . [optional]
            start (int): syntax: start=12  behavior: offset in matching result list, for pagination . [optional] if omitted the server will use the default value of 0
            summary_only (bool): syntax: summary-only={true,false}  behavior: only return the summary when a list is returned. Useful to get the list of available properties. . [optional] if omitted the server will use the default value of False
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            PdsProducts
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['identifier'] = \
            identifier
        return self.bundles_containing_product_endpoint.call_with_http_info(**kwargs)

